#ifndef NT2_INCLUDE_FUNCTIONS_SCALAR_GAMMALN_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SCALAR_GAMMALN_HPP_INCLUDED

#include <nt2/euler/include/functions/scalar/gammaln.hpp>

#endif
